Crate clap_documentation

Crate clap_documentation 

Autogenerate Markdown or AsciiDoc documentation for clap command-line tools

Structs

AsciiDocOptions
MarkdownOptions
Options to customize the structure of the output Markdown document.

Functions

help_asciidoc
Format the help information for command as asciidoc.
help_asciidoc_command
Format the help information for command as asciidoc.
help_asciidoc_command_custom
Format the help information for command as asciidoc, with custom options.
help_asciidoc_custom
Format the help information for command as asciidoc, with custom options.
help_markdown
Format the help information for command as Markdown.
help_markdown_command
Format the help information for command as Markdown.
help_markdown_command_custom
Format the help information for command as Markdown, with custom options.
help_markdown_custom
Format the help information for command as Markdown, with custom options.
print_help_asciidoc
Format the help information for command as asciidoc and print it.
print_help_markdown
Format the help information for command as Markdown and print it.