pub fn help_asciidoc_command_custom(
command: &Command,
options: &AsciiDocOptions,
) -> StringExpand description
Format the help information for command as asciidoc, with custom options.
pub fn help_asciidoc_command_custom(
command: &Command,
options: &AsciiDocOptions,
) -> StringFormat the help information for command as asciidoc, with custom options.